SurvRegCensCov-package: Weibull Regression for a Right-Censored Endpoint with Censored Covariates
Description
The main function SurvRegCens of this package allows estimation of a Weibull Regression for a right-censored endpoint, one arbitrarily censored covariate, and an arbitrary number of non-censored covariates. Additional functions allow to switch between different parametrizations of Weibull regression used by different R functions (ConvertWeibull, WeibullReg, WeibullDiag), inference for the mean difference of two arbitrarily censored Normal samples (NormalMeanDiffCens), and estimation of canonical parameters from censored samples for several distributional assumptions (ParamSampleCens).
Hubeaux, S. (2013).
Estimation from left- and/or interval-censored samples.
Technical report, Biostatistics Oncology, F. Hoffmann-La Roche Ltd.
Hubeaux, S. (2013).
Parametric Surival Regression Model with left- and/or interval-censored covariate.
Technical report, Biostatistics Oncology, F. Hoffmann-La Roche Ltd.
Lynn, H. S. (2001).
Maximum likelihood inference for left-censored HIV RNA data.
Stat. Med., 20, 33--45.
Sattar, A., Sinha, S. K. and Morris, N. J. (2012).
A Parametric Survival Model When a Covariate is Subject to Left-Censoring.
Biometrics & Biostatistics, 3.