WeibullDiag(formula, data = parent.frame(), labels = names(m$strata))Surv object, should only contain one categorical
predictor, or a set of indicators describing only one predictor.plot.survfit and the fun = "cloglog" option),
as well as a data set containing that information.plot.survfit and the option fun = "cloglog".data(larynx)
WeibullDiag(Surv(time, death) ~ stage, data = larynx)Run the code above in your browser using DataLab