WeibullReg performs Weibull regression using the survreg function, and transforms the
estimates to a more natural parameterization. Additionally, it produces hazard ratios (corresponding to the proportional
hazards interpretation), and event time ratios (corresponding to the accelerated failure time interpretation) for all
covariates.WeibullReg(formula, data = parent.frame(), conf.level = 0.95)Surv formula.formula.survreg model.vignette("weibull") of this package, or in the documentation for ConvertWeibull.ConvertWeibull. See also
survreg.data(larynx)
WR <- WeibullReg(Surv(time, death) ~ factor(stage) + age, data = larynx)
WRRun the code above in your browser using DataLab