Learn R Programming

SurvRegCensCov (version 1.3)

larynx: Survival Times of Larynx Cancer Patients

Description

A study of 90 males with laryngeal cancer was performed, comparing survival times. Each patient's age, year of diagnosis, and disease stage was noted, see Kardaun (1983) and Klein and Moeschberger (2003).

Usage

data(larynx)

Arguments

source

http://www.mcw.edu/FileLibrary/Groups/Biostatistics/Publicfiles/DataFromSection/DataFromSectionTXT/Data_from_section_1.8.txt

References

Kardaun, O. (1983). Statistical survival analysis of male larynx-cancer patients-a case study. Statistica Neerlandica, 37, 103--125. Klein, J. and Moeschberger, M. (2003). Survival analysis: techniques for censored and truncated data. 2nd edition, Springer.

Examples

Run this code
library(survival)
data(larynx)
Surv(larynx$time, larynx$death)

Run the code above in your browser using DataLab